import QtQuick 1.1
import XAHTMLEditorItem 1.0
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent
    objectName: "CommentInput"

    property string itemComment: ""
    property string itemPlaceholder: ""
    property alias text: commentField.text

    property alias toolbarVisible: toolbarContainer.visible
    property alias zoomButtonVisible: tbZoom.visible

    property bool isEditable: true

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    property int iconIndent: zoomButtonVisible ? 30 : 44
    property int iconSpacer: 2
    property int iconGroupSpacer: 16

    signal updated(string newComment);
    signal itemClicked();
    signal zoomRequested();
    signal focusRequested();

    property color tabPanelMarkerColor: "#d9d9d9"
    property Gradient tabPanelBackgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.5; color: "#dddddd" }
        GradientStop { position: 1.0; color: "white" }
    }

    function activateFocus() {
        commentField.focus = true;
        commentField.forceActiveFocus();

        focusRequested();
    }

    onItemCommentChanged: {
        console.log("QML onItemCommentChanged: " + itemComment)
        commentField.text = itemComment
//        detailsPanel.selectTab(itemPriority)
//        triggered(itemPriority)
    }

    Rectangle {
        id: detailsPanel
        anchors.fill: parent

        color: "transparent"

        Image {
            id: backgroundImageTop
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter

            source: "qrc:/icons/NoteBackgroundTopSlice001.png"

            Text {
                id: backgroundTitlePlaceholder
                anchors.top: parent.top
                anchors.topMargin: 3
                anchors.horizontalCenter: parent.horizontalCenter

                text: maincomponent.itemPlaceholder

                visible: (text.length > 0)

                font.family: "Helvetica Neue"
                font.pixelSize: 12
                font.bold: false

                color: "#aaaaaa"
            }

            MouseArea {
                anchors.fill: parent

                onPressed: {
                    itemClicked();
                    commentField.focus = true
                }
            }

            Item {
                id: toolbarContainer
                anchors.fill: parent
                anchors.topMargin: backgroundTitlePlaceholder.text.length > 0 ? 1 : 0;
                visible: false

                AIInspectorToolbarButton {
                    id: tbBold
                    anchors.left: parent.left
                    anchors.leftMargin: maincomponent.iconIndent
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontBold.png"

                    onTriggered: commentField.bold();
                }

                AIInspectorToolbarButton {
                    id: tbItalic
                    anchors.left: tbBold.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontItalic.png"

                    onTriggered: commentField.italic();
                }

                AIInspectorToolbarButton {
                    id: tbUnderlined
                    anchors.left: tbItalic.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontUnderlined.png"

                    onTriggered: commentField.underline();
                }

                ////////// Alignment

                AIInspectorToolbarButton {
                    id: tbAlignLeft
                    anchors.left: tbUnderlined.right
                    anchors.leftMargin: maincomponent.iconGroupSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontAlignLeft.png"

                    onTriggered: commentField.alignLeft();
                }

                AIInspectorToolbarButton {
                    id: tbAlignCenter
                    anchors.left: tbAlignLeft.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontAlignCenter.png"

                    onTriggered: commentField.alignCenter();
                }

                AIInspectorToolbarButton {
                    id: tbAlignRight
                    anchors.left: tbAlignCenter.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontAlignRight.png"

                    onTriggered: commentField.alignRight();
                }

                ////////// Lists and Indent

                AIInspectorToolbarButton {
                    id: tbBulletList
                    anchors.left: tbAlignRight.right
                    anchors.leftMargin: maincomponent.iconGroupSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontLI.png"

                    onTriggered: commentField.bulletList();
                }

                AIInspectorToolbarButton {
                    id: tbNumberedList
                    anchors.left: tbBulletList.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontNumbered.png"

                    onTriggered: commentField.numberedList();
                }

                AIInspectorToolbarButton {
                    id: tbIndent
                    anchors.left: tbNumberedList.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontIndent.png"

                    onTriggered: commentField.indent();
                }

                AIInspectorToolbarButton {
                    id: tbOutdent
                    anchors.left: tbIndent.right
                    anchors.leftMargin: maincomponent.iconSpacer
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/FontOutdent.png"

                    onTriggered: commentField.outdent();
                }

                ////////// Links

//                AIInspectorToolbarButton {
//                    id: tbLink
//                    anchors.left: tbOutdent.right
//                    anchors.leftMargin: maincomponent.iconGroupSpacer
//                    anchors.top: parent.top

//                    icon: "qrc:/icons/Formatting/FontLink.png"

//                    onTriggered: commentField.insertLink();
//                }

                AIInspectorToolbarButton {
                    id: tbLink
                    anchors.left: tbOutdent.right
                    anchors.leftMargin: 14
                    anchors.top: parent.top

                    icon: "qrc:/icons/Formatting/ActionMenu.png"

                    //onTriggered: commentField.insertLink();
                    onTriggered: commentField.showContextMenu(QtHandler.globalX()+mapToItem(maincomponent, 0, 0).x, QtHandler.globalY()+mapToItem(maincomponent, 0, 14).y+126);
                }

                ////////// Zoom

                AIInspectorToolbarButton {
                    id: tbZoom
                    anchors.left: tbLink.right
                    anchors.leftMargin: maincomponent.iconGroupSpacer
                    anchors.top: parent.top

                    visible: false

                    icon: "qrc:/icons/Formatting/FontZoom.png"

                    onTriggered: zoomRequested();
                }
            }
        }

        Image {
            id: backgroundImageMiddle
            anchors.top: backgroundImageTop.bottom
            anchors.bottom: backgroundImageBottom.top
            anchors.horizontalCenter: parent.horizontalCenter

            fillMode: Image.TileVertically

            source: "qrc:/icons/NoteBackgroundMiddleSlice001.png"

            XAHTMLEditorItem {
                id: commentField
                anchors.fill: parent
                anchors.rightMargin: 6

                onFocusChanged: {
                    if (focus) {
                        commentFieldMouseArea.visible = false;
                        toolbarContainer.visible = true;
                        backgroundTitlePlaceholder.visible = false;
                    }
                }

                onTextChanged: {
                    updated(text)
                    maincomponent.isModified = true
                }

                onDeactivated: {
                    focus = false;
                }

                Item {
                    id: topShadow
                    anchors.top: parent.top
                    anchors.topMargin: 0
                    anchors.left: parent.left
                    anchors.right: parent.right

                    XATopShadow {
                        id: topShadowLine

                        anchors.top: parent.top
                        anchors.left: parent.left
                        anchors.right: parent.right
                        height: 7
                    }
                }
            }
        }

        Image {
            id: backgroundImageBottom
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter

            source: "qrc:/icons/NoteBackgroundBottomSlice001.png"

            MouseArea {
                anchors.fill: parent

                onPressed: {
                    itemClicked();
                    commentField.focus = true
                }
            }
        }

    }
}
